@@ -5,13 +5,15 @@ import logging
 import multiprocessing
 import multiprocessing.pool
 import os
+from collections.abc import Generator
 from dataclasses import dataclass
 from fnmatch import fnmatch
-from typing import TYPE_CHECKING, Any, Generator
+from typing import TYPE_CHECKING, Any
 
 import ansiblelint.skip_utils
 import ansiblelint.utils
 from ansiblelint._internal.rules import LoadingFailureRule
+from ansiblelint.constants import States
 from ansiblelint.errors import MatchError
 from ansiblelint.file_utils import Lintable, expand_dirs_in_lintables
 from ansiblelint.rules.syntax_check import AnsibleSyntaxCheckRule
@@ -93,9 +95,6 @@ class Runner:
 
         # Exclusions should be evaluated only using absolute paths in order
         # to work correctly.
-        if not lintable:
-            return False
-
         abs_path = str(lintable.abspath)
         if self.project_dir and not abs_path.startswith(self.project_dir):
             _logger.debug(
@@ -122,14 +121,12 @@ class Runner:
                 _logger.debug("Excluded %s", lintable)
                 self.lintables.remove(lintable)
                 continue
-            try:
-                lintable.data
-            except RuntimeError as exc:
+            if isinstance(lintable.data, States) and lintable.exc:
                 matches.append(
                     MatchError(
                         filename=lintable,
-                        message=str(exc),
-                        details=str(exc.__cause__),
+                        message=str(lintable.exc),
+                        details=str(lintable.exc.__cause__),
                         rule=LoadingFailureRule(),
                     )
                 )
@@ -159,7 +156,6 @@ class Runner:
 
         # -- phase 2 ---
         if not matches:
-
             # do our processing only when ansible syntax check passed in order
             # to avoid causing runtime exceptions. Our processing is not as
             # resilient to be able process garbage.
@@ -207,7 +203,7 @@ class Runner:
                         self.lintables.add(child)
                         files.append(child)
                 except MatchError as exc:
-                    if not exc.filename:
+                    if not exc.filename:  # pragma: no branch
                         exc.filename = str(lintable.path)
                     exc.rule = LoadingFailureRule()
                     yield exc
@@ -217,9 +213,15 @@ class Runner:
 
 
 def _get_matches(rules: RulesCollection, options: Namespace) -> LintResult:
-
     lintables = ansiblelint.utils.get_lintables(opts=options, args=options.lintables)
 
+    for rule in rules:
+        if "unskippable" in rule.tags:
+            for entry in (*options.skip_list, *options.warn_list):
+                if rule.id == entry or entry.startswith(f"{rule.id}["):
+                    raise RuntimeError(
+                        f"Rule '{rule.id}' is unskippable, you cannot use it in 'skip_list' or 'warn_list'. Still, you could exclude the file."
+                    )
     matches = []
     checked_files: set[Lintable] = set()
     runner = Runner(
