@@ -6,18 +6,10 @@ import functools
 import logging
 import os
 import re
+from collections.abc import Iterator, Sequence
 from io import StringIO
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Dict,
-    Iterator,
-    Pattern,
-    Tuple,
-    Union,
-    cast,
-)
+from re import Pattern
+from typing import TYPE_CHECKING, Any, Callable, Union, cast
 
 import ruamel.yaml.events
 from ruamel.yaml.comments import CommentedMap, CommentedSeq, Format
@@ -34,6 +26,7 @@ from ruamel.yaml.tokens import CommentToken
 from yamllint.config import YamlLintConfig
 
 from ansiblelint.constants import (
+    ANNOTATION_KEYS,
     NESTED_TASK_KEYS,
     PLAYBOOK_TASK_KEYWORDS,
     SKIPPED_RULES_KEY,
@@ -66,9 +59,27 @@ rules:
   braces:
     min-spaces-inside: 0  # yamllint defaults to 0
     max-spaces-inside: 1  # yamllint defaults to 0
+  octal-values:
+    forbid-implicit-octal: true  # yamllint defaults to false
+    forbid-explicit-octal: true  # yamllint defaults to false
 """
 
 
+def deannotate(data: Any) -> Any:
+    """Remove our annotations like __file__ and __line__ and return a JSON serializable object."""
+    if isinstance(data, dict):
+        result = data.copy()
+        for key, value in data.items():
+            if key in ANNOTATION_KEYS:
+                del result[key]
+            else:
+                result[key] = deannotate(value)
+        return result
+    if isinstance(data, list):
+        return [deannotate(item) for item in data if item not in ANNOTATION_KEYS]
+    return data
+
+
 @functools.lru_cache(maxsize=1)
 def load_yamllint_config() -> YamlLintConfig:
     """Load our default yamllint config and any customized override file."""
@@ -151,6 +162,7 @@ def iter_tasks_in_file(
 
 def nested_items_path(
     data_collection: dict[Any, Any] | list[Any],
+    ignored_keys: Sequence[str] = (),
 ) -> Iterator[tuple[Any, Any, list[str | int]]]:
     """Iterate a nested data structure, yielding key/index, value, and parent_path.
 
@@ -211,12 +223,15 @@ def nested_items_path(
     # valid data, we better ignore NoneType
     if data_collection is None:
         return
-    yield from _nested_items_path(data_collection=data_collection, parent_path=[])
+    yield from _nested_items_path(
+        data_collection=data_collection, parent_path=[], ignored_keys=ignored_keys
+    )
 
 
 def _nested_items_path(
     data_collection: dict[Any, Any] | list[Any],
     parent_path: list[str | int],
+    ignored_keys: Sequence[str] = (),
 ) -> Iterator[tuple[Any, Any, list[str | int]]]:
     """Iterate through data_collection (internal implementation of nested_items_path).
 
@@ -226,7 +241,7 @@ def _nested_items_path(
     """
     # we have to cast each convert_to_tuples assignment or mypy complains
     # that both assignments (for dict and list) do not have the same type
-    convert_to_tuples_type = Callable[[], Iterator[Tuple[Union[str, int], Any]]]
+    convert_to_tuples_type = Callable[[], Iterator[tuple[Union[str, int], Any]]]
     if isinstance(data_collection, dict):
         convert_data_collection_to_tuples = cast(
             convert_to_tuples_type, functools.partial(data_collection.items)
@@ -241,7 +256,7 @@ def _nested_items_path(
             f"of type '{type(data_collection)}'"
         )
     for key, value in convert_data_collection_to_tuples():
-        if key in (SKIPPED_RULES_KEY, "__file__", "__line__"):
+        if key in (SKIPPED_RULES_KEY, "__file__", "__line__", *ignored_keys):
             continue
         yield key, value, parent_path
         if isinstance(value, (dict, list)):
@@ -567,7 +582,7 @@ class FormattedEmitter(Emitter):
     #     https://github.com/python/mypy/issues/4125
     #     To silence we have to ignore[override] both the @property and the method.
 
-    @property  # type: ignore[override]
+    @property
     def best_sequence_indent(self) -> int:
         """Return the configured sequence_indent or 2 for root level."""
         return 2 if self._is_root_level_sequence else self._sequence_indent
@@ -577,7 +592,7 @@ class FormattedEmitter(Emitter):
         """Configure how many columns to indent each sequence item (including the '-')."""
         self._sequence_indent = value
 
-    @property  # type: ignore[override]
+    @property
     def sequence_dash_offset(self) -> int:
         """Return the configured sequence_dash_offset or 0 for root level."""
         return 0 if self._is_root_level_sequence else self._sequence_dash_offset
@@ -590,6 +605,16 @@ class FormattedEmitter(Emitter):
     def choose_scalar_style(self) -> Any:
         """Select how to quote scalars if needed."""
         style = super().choose_scalar_style()
+        if (
+            style == ""
+            and self.event.value.startswith("0")
+            and len(self.event.value) > 1
+        ):
+            if self.event.tag == "tag:yaml.org,2002:int" and self.event.implicit[0]:
+                # ensures that "0123" string does not lose its quoting
+                self.event.tag = "tag:yaml.org,2002:str"
+                self.event.implicit = (True, True, True)
+            return '"'
         if style != "'":
             # block scalar, double quoted, etc.
             return style
@@ -895,7 +920,7 @@ class FormattedYAML(YAML):
                 elif quote_type == "double":
                     config["preferred_quote"] = '"'
 
-        return cast(Dict[str, Union[bool, int, str]], config)
+        return cast(dict[str, Union[bool, int, str]], config)
 
     @property  # type: ignore[override]
     def version(self) -> str | tuple[int, int]:
@@ -1080,3 +1105,33 @@ class FormattedYAML(YAML):
             FormattedEmitter.drop_octothorpe_protection(line) for line in lines
         )
         return text
+
+
+def clean_json(
+    obj: Any,
+    func: Callable[[str], Any] = lambda key: key.startswith("__")
+    if isinstance(key, str)
+    else False,
+) -> Any:
+    """
+    Remove all keys matching the condition from a nested JSON-like object.
+
+    :param obj: a JSON like object to clean, also returned for chaining.
+    :param func: a callable that takes a key in argument and return True for each key to delete
+    """
+    if isinstance(obj, dict):
+        for key in list(obj.keys()):
+            if func(key):
+                del obj[key]
+            else:
+                clean_json(obj[key], func)
+    elif isinstance(obj, list):
+        for i in reversed(range(len(obj))):
+            if func(obj[i]):
+                del obj[i]
+            else:
+                clean_json(obj[i], func)
+    else:
+        # neither a dict nor a list, do nothing
+        pass
+    return obj
